@@ -577,14 +577,6 @@ extern void clear_regs(struct tcb *tcp);
 extern int get_scno(struct tcb *);
 extern kernel_ulong_t get_rt_sigframe_addr(struct tcb *);
 
-/**
- * Convert a (shuffled) syscall number to the corresponding syscall name.
- *
- * @param scno Syscall number.
- * @return     String literal corresponding to the syscall number in case latter
- *             is valid; NULL otherwise.
- */
-extern const char *syscall_name(kernel_ulong_t scno);
 /**
  * Convert a pair of (raw) syscall number and arch (defined by an AUDIT_ARCH_*
  * constant) to the corresponding syscall name.  So far works only for arches
@@ -841,9 +833,29 @@ str_strip_prefix_len(const char *str, const char *prefix, size_t prefix_len)
 /** Print ellipsis if the last character is not '\0' */
 # define QUOTE_EXPECT_TRAILING_0		0x10
 /** Print string in hex (using '\xHH' notation). */
-# define QUOTE_FORCE_HEX			0x20
+# define QUOTE_FORCE_HEX			(QUOTE_OVERWRITE_HEXSTR | QUOTE_HEXSTR_ALL)
 /** Enclose the string in C comment syntax. */
 # define QUOTE_EMIT_COMMENT			0x40
+/** Override xflag setting with one of QUOTE_HEXSTR_[NA]* styles */
+# define QUOTE_OVERWRITE_HEXSTR			0x80
+
+/*
+ * bits 8..9 (mask 0x300) are used for supplying the respective hexstr setting
+ * if QUOTE_OVERWRITE_HEXSTR is set.
+ */
+# define QUOTE_HEXSTR_SHIFT			8
+/**
+ * Mask to be applied to a quoting style to extract the xflag overriding style
+ * part.
+ */
+# define QUOTE_HEXSTR_MASK			(0x3 << QUOTE_HEXSTR_SHIFT)
+static_assert((NUM_HEXSTR_OPTS - 1) <= (QUOTE_HEXSTR_MASK >> QUOTE_HEXSTR_SHIFT),
+	      "xflag options do not fit into QUOTE_HEXSTR_MASK");
+
+# define QUOTE_HEXSTR_NONE			(HEXSTR_NONE << QUOTE_HEXSTR_SHIFT)
+# define QUOTE_HEXSTR_ALL			(HEXSTR_ALL << QUOTE_HEXSTR_SHIFT)
+# define QUOTE_HEXSTR_NON_ASCII			(HEXSTR_NON_ASCII << QUOTE_HEXSTR_SHIFT)
+# define QUOTE_HEXSTR_NON_ASCII_CHARS		(HEXSTR_NON_ASCII_CHARS << QUOTE_HEXSTR_SHIFT)
 
 extern int string_quote(const char *, char *, unsigned int, unsigned int,
 			const char *escape_chars);
@@ -966,12 +978,9 @@ extern const char *sprinttime_usec(long long sec, unsigned long long usec);
 #  define MAX_ADDR_LEN 32
 # endif
 
-extern const char *sprint_mac_addr(const uint8_t addr[], size_t size);
 extern void print_mac_addr(const char *prefix,
 			   const uint8_t addr[], size_t size);
 
-extern const char *sprint_hwaddr(const uint8_t addr[], size_t size,
-				 uint32_t devtype);
 extern void print_hwaddr(const char *prefix,
 			 const uint8_t addr[], size_t size, uint32_t devtype);
 
@@ -1353,6 +1362,7 @@ DECL_IOCTL(gpio);
 DECL_IOCTL(inotify);
 DECL_IOCTL(kd);
 DECL_IOCTL(kvm);
+DECL_IOCTL(lirc);
 DECL_IOCTL(nbd);
 DECL_IOCTL(nsfs);
 DECL_IOCTL(ptp);
@@ -1465,7 +1475,6 @@ extern int ts_cmp(const struct timespec *, const struct timespec *);
 extern double ts_float(const struct timespec *);
 extern void ts_add(struct timespec *, const struct timespec *, const struct timespec *);
 extern void ts_sub(struct timespec *, const struct timespec *, const struct timespec *);
-extern void ts_mul(struct timespec *, const struct timespec *, uint64_t);
 extern void ts_div(struct timespec *, const struct timespec *, uint64_t);
 extern const struct timespec *ts_min(const struct timespec *, const struct timespec *);
 extern const struct timespec *ts_max(const struct timespec *, const struct timespec *);
@@ -1903,6 +1912,13 @@ scno_in_range(kernel_ulong_t scno)
 	return scno < nsyscalls;
 }
 
+/* Like scno_in_range but for the specified personality.  */
+static inline bool
+scno_pers_in_range(kernel_ulong_t scno, unsigned int pers)
+{
+	return scno < nsyscall_vec[pers];
+}
+
 /*
  * Checks whether scno is not out of range,
  * its corresponding sysent[scno].sys_func is non-NULL,
@@ -1916,6 +1932,15 @@ scno_is_valid(kernel_ulong_t scno)
 	       && !(sysent[scno].sys_flags & TRACE_INDIRECT_SUBCALL);
 }
 
+/* Like scno_is_valid but for the specified personality.  */
+static inline bool
+scno_pers_is_valid(kernel_ulong_t scno, unsigned int pers)
+{
+	return scno_pers_in_range(scno, pers)
+	       && sysent_vec[pers][scno].sys_func
+	       && !(sysent_vec[pers][scno].sys_flags & TRACE_INDIRECT_SUBCALL);
+}
+
 # define MPERS_FUNC_NAME__(prefix, name) prefix ## name
 # define MPERS_FUNC_NAME_(prefix, name) MPERS_FUNC_NAME__(prefix, name)
 # define MPERS_FUNC_NAME(name) MPERS_FUNC_NAME_(MPERS_PREFIX, name)
