@@ -2,7 +2,7 @@
  * Check decoding of io_uring_register syscall.
  *
  * Copyright (c) 2019 Dmitry V. Levin <ldv@strace.io>
- * Copyright (c) 2019-2021 The strace developers.
+ * Copyright (c) 2019-2022 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -23,7 +23,7 @@
 # define BIG_ADDR_MAYBE(addr_)
 # define BIG_ADDR_MASK 0
 #elif defined __arm__ || defined __i386__ || defined __mips__ \
-   || defined __powerpc__ || defined __riscv__ || defined __s390__ \
+   || defined __powerpc__ || defined __riscv || defined __s390__ \
    || defined __sparc__ || defined __tile__
 # define BIG_ADDR_MAYBE(addr_) addr_ " or "
 # define BIG_ADDR_MASK 0xffffffff00000000ULL
@@ -469,21 +469,22 @@ main(void)
 		{ ARG_STR(IORING_RESTRICTION_SQE_FLAGS_ALLOWED), true,
 		  "sqe_flags=", 0, "", false },
 		{ ARG_STR(IORING_RESTRICTION_SQE_FLAGS_ALLOWED), true,
-		  "sqe_flags=", 32, "IOSQE_BUFFER_SELECT", true },
+		  "sqe_flags=", 64, "IOSQE_CQE_SKIP_SUCCESS", true },
 		{ ARG_STR(IORING_RESTRICTION_SQE_FLAGS_ALLOWED), true,
 		  "sqe_flags=", 0xff, "IOSQE_FIXED_FILE|IOSQE_IO_DRAIN"
 				      "|IOSQE_IO_LINK|IOSQE_IO_HARDLINK"
 				      "|IOSQE_ASYNC|IOSQE_BUFFER_SELECT"
-				      "|0xc0",
+				      "|IOSQE_CQE_SKIP_SUCCESS"
+				      "|0x80",
 		  true },
 		{ ARG_STR(IORING_RESTRICTION_SQE_FLAGS_ALLOWED), true,
-		  "sqe_flags=", 192, " /* IOSQE_??? */", false },
+		  "sqe_flags=", 128, " /* IOSQE_??? */", false },
 		{ ARG_STR(IORING_RESTRICTION_SQE_FLAGS_REQUIRED), true,
 		  "sqe_flags=", 0, "", false },
 		{ ARG_STR(IORING_RESTRICTION_SQE_FLAGS_REQUIRED), true,
 		  "sqe_flags=", 1, "IOSQE_FIXED_FILE", true },
 		{ ARG_STR(IORING_RESTRICTION_SQE_FLAGS_REQUIRED), true,
-		  "sqe_flags=", 96, "IOSQE_BUFFER_SELECT|0x40", true },
+		  "sqe_flags=", 192, "IOSQE_CQE_SKIP_SUCCESS|0x80", true },
 		{ ARG_STR(IORING_RESTRICTION_SQE_FLAGS_REQUIRED), true,
 		  "sqe_flags=",	128, " /* IOSQE_??? */", false },
 		{ 4, " /* IORING_RESTRICTION_??? */", false, "", 0 },
